@@ -43,9 +43,6 @@
 #include "qbluetoothaddress.h"
 #include "qbluetoothuuid.h"
 
-#include "bluez/manager_p.h"
-#include "bluez/adapter_p.h"
-#include "bluez/device_p.h"
 #include "bluez/bluez5_helper_p.h"
 #include "bluez/objectmanager_p.h"
 #include "bluez/adapter1_bluez5_p.h"
@@ -59,46 +56,28 @@ Q_DECLARE_LOGGING_CATEGORY(QT_BT_BLUEZ)
 
 QBluetoothDeviceDiscoveryAgentPrivate::QBluetoothDeviceDiscoveryAgentPrivate(
     const QBluetoothAddress &deviceAdapter, QBluetoothDeviceDiscoveryAgent *parent) :
-    lastError(QBluetoothDeviceDiscoveryAgent::NoError),
     m_adapterAddress(deviceAdapter),
-    pendingCancel(false),
-    pendingStart(false),
-    useExtendedDiscovery(false),
-    lowEnergySearchTimeout(-1), // remains -1 on BlueZ 4 -> timeout not supported
     q_ptr(parent)
 {
-    if (isBluez5()) {
-        lowEnergySearchTimeout = 20000;
-        managerBluez5 = new OrgFreedesktopDBusObjectManagerInterface(
-                                           QStringLiteral("org.bluez"),
-                                           QStringLiteral("/"),
-                                           QDBusConnection::systemBus(), parent);
-        QObject::connect(managerBluez5,
-                         &OrgFreedesktopDBusObjectManagerInterface::InterfacesAdded,
-                         q_ptr,
-                         [this](const QDBusObjectPath &objectPath, InterfaceList interfacesAndProperties) {
-            this->_q_InterfacesAdded(objectPath, interfacesAndProperties);
-        });
+    initializeBluez5();
+    manager = new OrgFreedesktopDBusObjectManagerInterface(
+                                       QStringLiteral("org.bluez"),
+                                       QStringLiteral("/"),
+                                       QDBusConnection::systemBus(), parent);
+    QObject::connect(manager,
+                     &OrgFreedesktopDBusObjectManagerInterface::InterfacesAdded,
+                     q_ptr,
+                     [this](const QDBusObjectPath &objectPath, InterfaceList interfacesAndProperties) {
+        this->_q_InterfacesAdded(objectPath, interfacesAndProperties);
+    });
 
-        // start private address monitoring
-        BluetoothManagement::instance();
-    } else {
-        manager = new OrgBluezManagerInterface(QStringLiteral("org.bluez"), QStringLiteral("/"),
-                                           QDBusConnection::systemBus(), parent);
-        QObject::connect(&extendedDiscoveryTimer,
-                         &QTimer::timeout, q_ptr, [this]() {
-            this->_q_extendedDeviceDiscoveryTimeout();
-        });
-        extendedDiscoveryTimer.setInterval(10000);
-        extendedDiscoveryTimer.setSingleShot(true);
-    }
-    inquiryType = QBluetoothDeviceDiscoveryAgent::GeneralUnlimitedInquiry;
+    // start private address monitoring
+    BluetoothManagement::instance();
 }
 
 QBluetoothDeviceDiscoveryAgentPrivate::~QBluetoothDeviceDiscoveryAgentPrivate()
 {
     delete adapter;
-    delete adapterBluez5;
 }
 
 //TODO: Qt6 remove the pendingCancel/pendingStart logic as it is cumbersome.
@@ -115,7 +94,7 @@ bool QBluetoothDeviceDiscoveryAgentPrivate::isActive() const
     if (pendingCancel)
         return false; //TODO Qt6: remove pending[Cancel|Start] logic (see comment above)
 
-    return (adapter || adapterBluez5);
+    return adapter;
 }
 
 QBluetoothDeviceDiscoveryAgent::DiscoveryMethods QBluetoothDeviceDiscoveryAgent::supportedDiscoveryMethods()
@@ -125,10 +104,6 @@ QBluetoothDeviceDiscoveryAgent::DiscoveryMethods QBluetoothDeviceDiscoveryAgent:
 
 void QBluetoothDeviceDiscoveryAgentPrivate::start(QBluetoothDeviceDiscoveryAgent::DiscoveryMethods methods)
 {
-    // Currently both BlueZ backends do not distinguish discovery methods.
-    // The DBus API's always return both device types. Therefore we ignore
-    // the passed in methods.
-
     if (pendingCancel == true) {
         pendingStart = true;
         return;
@@ -137,102 +112,6 @@ void QBluetoothDeviceDiscoveryAgentPrivate::start(QBluetoothDeviceDiscoveryAgent
     discoveredDevices.clear();
     devicesProperties.clear();
 
-    if (managerBluez5) {
-        startBluez5(methods);
-        return;
-    }
-
-    QDBusPendingReply<QDBusObjectPath> reply;
-
-    if (m_adapterAddress.isNull())
-        reply = manager->DefaultAdapter();
-    else
-        reply = manager->FindAdapter(m_adapterAddress.toString());
-    reply.waitForFinished();
-
-    if (reply.isError()) {
-        errorString = reply.error().message();
-        qCDebug(QT_BT_BLUEZ) << Q_FUNC_INFO << "ERROR: " << errorString;
-        lastError = QBluetoothDeviceDiscoveryAgent::InputOutputError;
-        Q_Q(QBluetoothDeviceDiscoveryAgent);
-        emit q->error(lastError);
-        return;
-    }
-
-    adapter = new OrgBluezAdapterInterface(QStringLiteral("org.bluez"), reply.value().path(),
-                                           QDBusConnection::systemBus());
-
-    Q_Q(QBluetoothDeviceDiscoveryAgent);
-    QObject::connect(adapter, &OrgBluezAdapterInterface::DeviceFound,
-                     q, [this](const QString &address, const QVariantMap &dict) {
-        this->_q_deviceFound(address, dict);
-    });
-    QObject::connect(adapter, &OrgBluezAdapterInterface::PropertyChanged,
-                     q, [this](const QString &name, const QDBusVariant &value) {
-        this->_q_propertyChanged(name, value);
-    });
-
-    QDBusPendingReply<QVariantMap> propertiesReply = adapter->GetProperties();
-    propertiesReply.waitForFinished();
-    if (propertiesReply.isError()) {
-        errorString = propertiesReply.error().message();
-        delete adapter;
-        adapter = nullptr;
-        qCDebug(QT_BT_BLUEZ) << Q_FUNC_INFO << "ERROR: " << errorString;
-        lastError = QBluetoothDeviceDiscoveryAgent::InputOutputError;
-        Q_Q(QBluetoothDeviceDiscoveryAgent);
-        delete adapter;
-        adapter = nullptr;
-        emit q->error(lastError);
-        return;
-    }
-
-    if (!propertiesReply.value().value(QStringLiteral("Powered")).toBool()) {
-        qCDebug(QT_BT_BLUEZ) << "Aborting device discovery due to offline Bluetooth Adapter";
-        lastError = QBluetoothDeviceDiscoveryAgent::PoweredOffError;
-        errorString = QBluetoothDeviceDiscoveryAgent::tr("Device is powered off");
-        delete adapter;
-        adapter = nullptr;
-        emit q->error(lastError);
-        return;
-    }
-
-    if (propertiesReply.value().value(QStringLiteral("Discovering")).toBool()) {
-        /*  The discovery session is already ongoing. BTLE devices are advertised
-            immediately after the start of the device discovery session. Hence if the
-            session is already ongoing, we have just missed the BTLE device
-            advertisement.
-
-            This always happens during the second device discovery run in
-            the current process. The first discovery doesn't have this issue.
-            As to why the discovery session remains active despite the previous one
-            being terminated is not known. This may be a bug in Bluez4.
-
-            To workaround this issue we have to wait for two discovery
-            sessions cycles.
-        */
-        qCDebug(QT_BT_BLUEZ) << "Using BTLE device discovery workaround.";
-        useExtendedDiscovery = true;
-    } else {
-        useExtendedDiscovery = false;
-    }
-
-    QDBusPendingReply<> discoveryReply = adapter->StartDiscovery();
-    discoveryReply.waitForFinished();
-    if (discoveryReply.isError()) {
-        delete adapter;
-        adapter = nullptr;
-        errorString = discoveryReply.error().message();
-        lastError = QBluetoothDeviceDiscoveryAgent::InputOutputError;
-        Q_Q(QBluetoothDeviceDiscoveryAgent);
-        qCDebug(QT_BT_BLUEZ) << Q_FUNC_INFO << "ERROR: " << errorString;
-        emit q->error(lastError);
-        return;
-    }
-}
-
-void QBluetoothDeviceDiscoveryAgentPrivate::startBluez5(QBluetoothDeviceDiscoveryAgent::DiscoveryMethods methods)
-{
     Q_Q(QBluetoothDeviceDiscoveryAgent);
 
     bool ok = false;
@@ -241,21 +120,20 @@ void QBluetoothDeviceDiscoveryAgentPrivate::startBluez5(QBluetoothDeviceDiscover
         qCWarning(QT_BT_BLUEZ) << "Cannot find Bluez 5 adapter for device search" << ok;
         lastError = QBluetoothDeviceDiscoveryAgent::InputOutputError;
         errorString = QBluetoothDeviceDiscoveryAgent::tr("Cannot find valid Bluetooth adapter.");
-        q->error(lastError);
+        q->errorOccurred(lastError);
         return;
     }
 
-    adapterBluez5 = new OrgBluezAdapter1Interface(QStringLiteral("org.bluez"),
-                                                  adapterPath,
-                                                  QDBusConnection::systemBus());
+    adapter = new OrgBluezAdapter1Interface(QStringLiteral("org.bluez"), adapterPath,
+                                            QDBusConnection::systemBus());
 
-    if (!adapterBluez5->powered()) {
+    if (!adapter->powered()) {
         qCDebug(QT_BT_BLUEZ) << "Aborting device discovery due to offline Bluetooth Adapter";
         lastError = QBluetoothDeviceDiscoveryAgent::PoweredOffError;
         errorString = QBluetoothDeviceDiscoveryAgent::tr("Device is powered off");
-        delete adapterBluez5;
-        adapterBluez5 = nullptr;
-        emit q->error(lastError);
+        delete adapter;
+        adapter = nullptr;
+        emit q->errorOccurred(lastError);
         return;
     }
 
@@ -269,7 +147,7 @@ void QBluetoothDeviceDiscoveryAgentPrivate::startBluez5(QBluetoothDeviceDiscover
 
     // older BlueZ 5.x versions don't have this function
     // filterReply returns UnknownMethod which we ignore
-    QDBusPendingReply<> filterReply = adapterBluez5->SetDiscoveryFilter(map);
+    QDBusPendingReply<> filterReply = adapter->SetDiscoveryFilter(map);
     filterReply.waitForFinished();
     if (filterReply.isError()) {
         if (filterReply.error().type() == QDBusError::Other
@@ -278,23 +156,34 @@ void QBluetoothDeviceDiscoveryAgentPrivate::startBluez5(QBluetoothDeviceDiscover
             lastError = QBluetoothDeviceDiscoveryAgent::UnsupportedDiscoveryMethod;
             errorString = QBluetoothDeviceDiscoveryAgent::tr("One or more device discovery methods "
                                                              "are not supported on this platform");
-            delete adapterBluez5;
-            adapterBluez5 = nullptr;
-            emit q->error(lastError);
+            delete adapter;
+            adapter = nullptr;
+            emit q->errorOccurred(lastError);
             return;
         } else if (filterReply.error().type() != QDBusError::UnknownMethod) {
             qCDebug(QT_BT_BLUEZ) << "SetDiscoveryFilter failed:" << filterReply.error();
         }
     }
 
-    QtBluezDiscoveryManager::instance()->registerDiscoveryInterest(adapterBluez5->path());
+    QtBluezDiscoveryManager::instance()->registerDiscoveryInterest(adapter->path());
     QObject::connect(QtBluezDiscoveryManager::instance(), &QtBluezDiscoveryManager::discoveryInterrupted,
                      q, [this](const QString &path){
         this->_q_discoveryInterrupted(path);
     });
+    OrgFreedesktopDBusPropertiesInterface *prop = new OrgFreedesktopDBusPropertiesInterface(
+                QStringLiteral("org.bluez"), QStringLiteral(""), QDBusConnection::systemBus());
+    QObject::connect(prop, &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged,
+                     q, [this](const QString &interface, const QVariantMap &changedProperties,
+                     const QStringList &invalidatedProperties,
+                     const QDBusMessage &signal) {
+        this->_q_PropertiesChanged(interface, signal.path(), changedProperties, invalidatedProperties);
+    });
+
+    // remember what we have to cleanup
+    propertyMonitors.append(prop);
 
     // collect initial set of information
-    QDBusPendingReply<ManagedObjectList> reply = managerBluez5->GetManagedObjects();
+    QDBusPendingReply<ManagedObjectList> reply = manager->GetManagedObjects();
     reply.waitForFinished();
     if (!reply.isError()) {
         ManagedObjectList managedObjectList = reply.value();
@@ -307,10 +196,10 @@ void QBluetoothDeviceDiscoveryAgentPrivate::startBluez5(QBluetoothDeviceDiscover
 
                 if (iface == QStringLiteral("org.bluez.Device1")) {
 
-                    if (path.path().indexOf(adapterBluez5->path()) != 0)
+                    if (path.path().indexOf(adapter->path()) != 0)
                         continue; //devices whose path doesn't start with same path we skip
 
-                    deviceFoundBluez5(path.path(), jt.value());
+                    deviceFound(path.path(), jt.value());
                     if (!isActive()) // Can happen if stop() was called from a slot in user code.
                       return;
                 }
@@ -336,72 +225,13 @@ void QBluetoothDeviceDiscoveryAgentPrivate::startBluez5(QBluetoothDeviceDiscover
 
 void QBluetoothDeviceDiscoveryAgentPrivate::stop()
 {
-    if (!adapter && !adapterBluez5)
+    if (!adapter)
         return;
 
     qCDebug(QT_BT_BLUEZ) << Q_FUNC_INFO;
     pendingCancel = true;
     pendingStart = false;
-    if (adapter) {
-        QDBusPendingReply<> reply = adapter->StopDiscovery();
-        reply.waitForFinished();
-    } else {
-        _q_discoveryFinished();
-    }
-}
-
-void QBluetoothDeviceDiscoveryAgentPrivate::_q_deviceFound(const QString &address,
-                                                           const QVariantMap &dict)
-{
-    const QBluetoothAddress btAddress(address);
-    const QString btName = dict.value(QStringLiteral("Name")).toString();
-    quint32 btClass = dict.value(QStringLiteral("Class")).toUInt();
-
-    qCDebug(QT_BT_BLUEZ) << "Discovered: " << address << btName
-                         << "Num UUIDs" << dict.value(QStringLiteral("UUIDs")).toStringList().count()
-                         << "total device" << discoveredDevices.count() << "cached"
-                         << dict.value(QStringLiteral("Cached")).toBool()
-                         << "RSSI" << dict.value(QStringLiteral("RSSI")).toInt();
-
-    QBluetoothDeviceInfo device(btAddress, btName, btClass);
-    if (dict.value(QStringLiteral("RSSI")).isValid())
-        device.setRssi(dict.value(QStringLiteral("RSSI")).toInt());
-    QVector<QBluetoothUuid> uuids;
-    const QStringList uuidStrings
-            = dict.value(QLatin1String("UUIDs")).toStringList();
-    for (const QString &u : uuidStrings)
-        uuids.append(QBluetoothUuid(u));
-    device.setServiceUuids(uuids);
-    device.setCached(dict.value(QStringLiteral("Cached")).toBool());
-
-
-    /*
-     * Bluez v4.1 does not have extra bit which gives information if device is Bluetooth
-     * Low Energy device and the way to discover it is with Class property of the Bluetooth device.
-     * Low Energy devices do not have property Class.
-     */
-    if (btClass == 0)
-        device.setCoreConfigurations(QBluetoothDeviceInfo::LowEnergyCoreConfiguration);
-    else
-        device.setCoreConfigurations(QBluetoothDeviceInfo::BaseRateCoreConfiguration);
-    for (int i = 0; i < discoveredDevices.size(); i++) {
-        if (discoveredDevices[i].address() == device.address()) {
-            if (discoveredDevices[i] == device) {
-                qCDebug(QT_BT_BLUEZ) << "Duplicate: " << address;
-                return;
-            }
-            discoveredDevices.replace(i, device);
-            Q_Q(QBluetoothDeviceDiscoveryAgent);
-            qCDebug(QT_BT_BLUEZ) << "Updated: " << address;
-
-            emit q->deviceDiscovered(device);
-            return; // this works if the list doesn't contain duplicates. Don't let it.
-        }
-    }
-    qCDebug(QT_BT_BLUEZ) << "Emit: " << address;
-    discoveredDevices.append(device);
-    Q_Q(QBluetoothDeviceDiscoveryAgent);
-    emit q->deviceDiscovered(device);
+    _q_discoveryFinished();
 }
 
 // Returns invalid QBluetoothDeviceInfo in case of error
@@ -417,7 +247,7 @@ static QBluetoothDeviceInfo createDeviceInfoFromBluez5Device(const QVariantMap&
     QBluetoothDeviceInfo deviceInfo(btAddress, btName, btClass);
     deviceInfo.setRssi(qvariant_cast<short>(properties[QStringLiteral("RSSI")]));
 
-    QVector<QBluetoothUuid> uuids;
+    QList<QBluetoothUuid> uuids;
     bool foundLikelyLowEnergyUuid = false;
     const QStringList foundUuids = qvariant_cast<QStringList>(properties[QStringLiteral("UUIDs")]);
     for (const auto &u: foundUuids) {
@@ -429,7 +259,8 @@ static QBluetoothDeviceInfo createDeviceInfoFromBluez5Device(const QVariantMap&
             //once we found one BTLE service we are done
             bool ok = false;
             quint16 shortId = id.toUInt16(&ok);
-            if (ok && ((shortId & QBluetoothUuid::GenericAccess) == QBluetoothUuid::GenericAccess))
+            quint16 genericAccessInt = static_cast<quint16>(QBluetoothUuid::ServiceClassUuid::GenericAccess);
+            if (ok && ((shortId & genericAccessInt) == genericAccessInt))
                 foundLikelyLowEnergyUuid = true;
         }
         uuids.append(id);
@@ -453,8 +284,8 @@ static QBluetoothDeviceInfo createDeviceInfoFromBluez5Device(const QVariantMap&
     return deviceInfo;
 }
 
-void QBluetoothDeviceDiscoveryAgentPrivate::deviceFoundBluez5(const QString &devicePath,
-                                                              const QVariantMap &properties)
+void QBluetoothDeviceDiscoveryAgentPrivate::deviceFound(const QString &devicePath,
+                                                        const QVariantMap &properties)
 {
     Q_Q(QBluetoothDeviceDiscoveryAgent);
 
@@ -462,8 +293,8 @@ void QBluetoothDeviceDiscoveryAgentPrivate::deviceFoundBluez5(const QString &dev
         return;
 
     auto deviceAdapter = qvariant_cast<QDBusObjectPath>(properties[QStringLiteral("Adapter")]);
-     if (deviceAdapter.path() != adapterBluez5->path())
-         return;
+    if (deviceAdapter.path() != adapter->path())
+        return;
 
     // read information
     QBluetoothDeviceInfo deviceInfo = createDeviceInfoFromBluez5Device(properties);
@@ -476,17 +307,6 @@ void QBluetoothDeviceDiscoveryAgentPrivate::deviceFoundBluez5(const QString &dev
                          << "RSSI" << deviceInfo.rssi()
                          << "Num ManufacturerData" << deviceInfo.manufacturerData().size();
 
-    OrgFreedesktopDBusPropertiesInterface *prop = new OrgFreedesktopDBusPropertiesInterface(
-                QStringLiteral("org.bluez"), devicePath, QDBusConnection::systemBus(), q);
-    QObject::connect(prop, &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged,
-                     q, [this](const QString &interface, const QVariantMap &changedProperties,
-                            const QStringList &invalidatedProperties) {
-        this->_q_PropertiesChanged(interface, changedProperties, invalidatedProperties);
-    });
-
-    // remember what we have to cleanup
-    propertyMonitors.append(prop);
-
     // Cache the properties so we do not have to access dbus every time to get a value
     devicesProperties[devicePath] = properties;
 
@@ -507,69 +327,6 @@ void QBluetoothDeviceDiscoveryAgentPrivate::deviceFoundBluez5(const QString &dev
     emit q->deviceDiscovered(deviceInfo);
 }
 
-void QBluetoothDeviceDiscoveryAgentPrivate::_q_propertyChanged(const QString &name,
-                                                               const QDBusVariant &value)
-{
-    qCDebug(QT_BT_BLUEZ) << Q_FUNC_INFO << name << value.variant();
-
-    if (name == QLatin1String("Discovering")) {
-      if (!value.variant().toBool()) {
-            Q_Q(QBluetoothDeviceDiscoveryAgent);
-            if (pendingCancel && !pendingStart) {
-                adapter->deleteLater();
-                adapter = nullptr;
-
-                pendingCancel = false;
-                emit q->canceled();
-            } else if (pendingStart) {
-                adapter->deleteLater();
-                adapter = nullptr;
-
-                pendingStart = false;
-                pendingCancel = false;
-                // start parameter ignored since Bluez 4 doesn't distinguish them
-                start(QBluetoothDeviceDiscoveryAgent::ClassicMethod
-                      | QBluetoothDeviceDiscoveryAgent::LowEnergyMethod);
-            } else {
-                 // happens when agent is created while other agent called StopDiscovery()
-                if (!adapter)
-                    return;
-
-                if (useExtendedDiscovery) {
-                    useExtendedDiscovery = false;
-                    /* We don't use the Start/StopDiscovery combo here
-                       Using this combo surppresses the BTLE device.
-                    */
-                    extendedDiscoveryTimer.start();
-                    return;
-                }
-
-                QDBusPendingReply<> reply = adapter->StopDiscovery();
-                reply.waitForFinished();
-                adapter->deleteLater();
-                adapter = nullptr;
-                emit q->finished();
-            }
-        } else {
-            if (extendedDiscoveryTimer.isActive())
-                extendedDiscoveryTimer.stop();
-        }
-    }
-}
-
-void QBluetoothDeviceDiscoveryAgentPrivate::_q_extendedDeviceDiscoveryTimeout()
-{
-
-    if (adapter) {
-        adapter->deleteLater();
-        adapter = nullptr;
-    }
-    if (isActive()) {
-        Q_Q(QBluetoothDeviceDiscoveryAgent);
-        emit q->finished();
-    }
-}
-
 void QBluetoothDeviceDiscoveryAgentPrivate::_q_InterfacesAdded(const QDBusObjectPath &object_path,
                                                                InterfaceList interfaces_and_properties)
 {
@@ -580,8 +337,9 @@ void QBluetoothDeviceDiscoveryAgentPrivate::_q_InterfacesAdded(const QDBusObject
 
     if (interfaces_and_properties.contains(QStringLiteral("org.bluez.Device1"))) {
         // device interfaces belonging to different adapter
-        // will be filtered out by deviceFoundBluez5();
-        deviceFoundBluez5(object_path.path(), interfaces_and_properties[QStringLiteral("org.bluez.Device1")]);
+        // will be filtered out by deviceFound();
+        deviceFound(object_path.path(),
+                    interfaces_and_properties[QStringLiteral("org.bluez.Device1")]);
     }
 }
 
@@ -593,13 +351,13 @@ void QBluetoothDeviceDiscoveryAgentPrivate::_q_discoveryFinished()
         discoveryTimer->stop();
 
     QtBluezDiscoveryManager::instance()->disconnect(q);
-    QtBluezDiscoveryManager::instance()->unregisterDiscoveryInterest(adapterBluez5->path());
+    QtBluezDiscoveryManager::instance()->unregisterDiscoveryInterest(adapter->path());
 
     qDeleteAll(propertyMonitors);
     propertyMonitors.clear();
 
-    delete adapterBluez5;
-    adapterBluez5 = nullptr;
+    delete adapter;
+    adapter = nullptr;
 
     if (pendingCancel && !pendingStart) {
         pendingCancel = false;
@@ -621,7 +379,7 @@ void QBluetoothDeviceDiscoveryAgentPrivate::_q_discoveryInterrupted(const QStrin
     if (!q->isActive())
         return;
 
-    if (path == adapterBluez5->path()) {
+    if (path == adapter->path()) {
         qCWarning(QT_BT_BLUEZ) << "Device discovery aborted due to unexpected adapter changes from another process.";
 
         if (discoveryTimer)
@@ -631,16 +389,17 @@ void QBluetoothDeviceDiscoveryAgentPrivate::_q_discoveryInterrupted(const QStrin
         // no need to call unregisterDiscoveryInterest since QtBluezDiscoveryManager
         // does this automatically when emitting discoveryInterrupted(QString) signal
 
-        delete adapterBluez5;
-        adapterBluez5 = nullptr;
+        delete adapter;
+        adapter = nullptr;
 
         errorString = QBluetoothDeviceDiscoveryAgent::tr("Bluetooth adapter error");
         lastError = QBluetoothDeviceDiscoveryAgent::InputOutputError;
-        emit q->error(lastError);
+        emit q->errorOccurred(lastError);
     }
 }
 
 void QBluetoothDeviceDiscoveryAgentPrivate::_q_PropertiesChanged(const QString &interface,
+                                                                 const QString &path,
                                                                  const QVariantMap &changed_properties,
                                                                  const QStringList &invalidated_properties)
 {
@@ -648,12 +407,6 @@ void QBluetoothDeviceDiscoveryAgentPrivate::_q_PropertiesChanged(const QString &
     if (interface != QStringLiteral("org.bluez.Device1"))
         return;
 
-    OrgFreedesktopDBusPropertiesInterface *props =
-            qobject_cast<OrgFreedesktopDBusPropertiesInterface *>(q->sender());
-    if (!props)
-        return;
-
-    const QString path = props->path();
     if (!devicesProperties.contains(path))
         return;
 
